package token_test

import (
	"errors"
	"testing"

	"git.akyoto.dev/cli/q/src/token"
	"git.akyoto.dev/go/assert"
)

func TestIndexKind(t *testing.T) {
	tokens := token.Tokenize([]byte("a{{}}"))
	assert.Equal(t, tokens.IndexKind(token.NewLine), -1)
	assert.Equal(t, tokens.LastIndexKind(token.NewLine), -1)
	assert.Equal(t, tokens.IndexKind(token.BlockStart), 1)
	assert.Equal(t, tokens.LastIndexKind(token.BlockStart), 2)
	assert.Equal(t, tokens.IndexKind(token.BlockEnd), 3)
	assert.Equal(t, tokens.LastIndexKind(token.BlockEnd), 4)
}

func TestSplit(t *testing.T) {
	src := []byte("1+2,3*4,5*6,7+8")
	tokens := token.Tokenize(src)
	parameters := []string{}

	err := tokens.Split(func(parameter token.List) error {
		parameters = append(parameters, parameter.Text(src))
		return nil
	})

	assert.Nil(t, err)
	assert.DeepEqual(t, parameters, []string{"1+2", "3*4", "5*6", "7+8"})

	err = tokens.Split(func(parameter token.List) error {
		return errors.New("error")
	})

	assert.NotNil(t, err)
	assert.Equal(t, err.Error(), "error")
}
